@@ -85,7 +85,7 @@ class TestCLIAlias(CuratorTestCase):
                     )
         self.assertEqual(
             {'dummy': {'aliases': {}}, 'my_index': {'aliases': {}}},
-            self.client.indices.get_aliases()
+            self.client.indices.get_alias(index='dummy,my_index')
         )
     def test_add_only_skip_closed(self):
         alias = 'testalias'
@@ -128,25 +128,115 @@ class TestCLIAlias(CuratorTestCase):
                     ],
                     )
         self.assertEqual(
-            {'dummy': {'aliases': {}}, 'my_index': {'aliases': {alias: {}}}},
-            self.client.indices.get_aliases()
+            {u'my_index': {u'aliases': {alias: {}}}},
+            self.client.indices.get_alias(name=alias)
         )
-    # def test_add_only_huge_list(self):
-    #     alias = 'testalias'
-    #     self.write_config(
-    #         self.args['configfile'], testvars.client_config.format(host, port))
-    #     self.write_config(self.args['actionfile'],
-    #         testvars.alias_add_only.format(alias))
-    #     self.create_indices(365)
-    #     test = clicktest.CliRunner()
-    #     result = test.invoke(
-    #                 curator.cli,
-    #                 [
-    #                     '--config', self.args['configfile'],
-    #                     self.args['actionfile']
-    #                 ],
-    #                 )
-    #     self.assertEquals(365, len(self.client.indices.get_alias(name=alias)))
+    def test_add_with_empty_remove(self):
+        alias = 'testalias'
+        self.write_config(
+            self.args['configfile'], testvars.client_config.format(host, port))
+        self.write_config(self.args['actionfile'],
+            testvars.alias_add_with_empty_remove.format(alias))
+        self.create_index('my_index')
+        self.create_index('dummy')
+        self.client.indices.put_alias(index='dummy', name=alias)
+        test = clicktest.CliRunner()
+        result = test.invoke(
+                    curator.cli,
+                    [
+                        '--config', self.args['configfile'],
+                        self.args['actionfile']
+                    ],
+                    )
+        self.assertEqual(
+            {'dummy': {'aliases': {alias: {}}},'my_index': {'aliases': {alias: {}}}},
+            self.client.indices.get_alias()
+        )
+    def test_remove_with_empty_add(self):
+        alias = 'testalias'
+        self.write_config(
+            self.args['configfile'], testvars.client_config.format(host, port))
+        self.write_config(self.args['actionfile'],
+            testvars.alias_remove_with_empty_add.format(alias))
+        self.create_index('my_index')
+        self.create_index('dummy')
+        self.client.indices.put_alias(index='dummy,my_index', name=alias)
+        test = clicktest.CliRunner()
+        result = test.invoke(
+                    curator.cli,
+                    [
+                        '--config', self.args['configfile'],
+                        self.args['actionfile']
+                    ],
+                    )
+        self.assertEqual(
+            {'dummy': {'aliases': {}},'my_index': {'aliases': {alias: {}}}},
+            self.client.indices.get_alias()
+        )
+    def test_add_with_empty_list(self):
+        alias = 'testalias'
+        self.write_config(
+            self.args['configfile'], testvars.client_config.format(host, port))
+        self.write_config(self.args['actionfile'],
+            testvars.alias_add_remove_empty.format(alias, 'du', 'rickroll'))
+        self.create_index('my_index')
+        self.create_index('dummy')
+        self.client.indices.put_alias(index='dummy', name=alias)
+        test = clicktest.CliRunner()
+        result = test.invoke(
+                    curator.cli,
+                    [
+                        '--config', self.args['configfile'],
+                        self.args['actionfile']
+                    ],
+                    )
+        self.assertEqual(
+            {'dummy': {'aliases': {alias: {}}}, 'my_index': {'aliases': {}}},
+            self.client.indices.get_alias()
+        )
+    def test_remove_with_empty_list(self):
+        alias = 'testalias'
+        self.write_config(
+            self.args['configfile'], testvars.client_config.format(host, port))
+        self.write_config(self.args['actionfile'],
+            testvars.alias_add_remove_empty.format(alias, 'rickroll', 'my'))
+        self.create_index('my_index')
+        self.create_index('dummy')
+        self.client.indices.put_alias(index='dummy', name=alias)
+        test = clicktest.CliRunner()
+        result = test.invoke(
+                    curator.cli,
+                    [
+                        '--config', self.args['configfile'],
+                        self.args['actionfile']
+                    ],
+                    )
+        self.assertEqual(
+            {'dummy': {'aliases': {alias: {}}}, 'my_index': {'aliases': {}}},
+            self.client.indices.get_alias()
+        )
+    def test_remove_index_not_in_alias(self):
+        alias = 'testalias'
+        self.write_config(
+            self.args['configfile'], testvars.client_config.format(host, port))
+        self.write_config(self.args['actionfile'],
+            testvars.alias_remove_index_not_there.format(alias,'my'))
+        self.create_index('my_index1')
+        self.create_index('my_index2')
+        self.client.indices.put_alias(index='my_index1', name=alias)
+        test = clicktest.CliRunner()
+        result = test.invoke(
+                    curator.cli,
+                    [
+                        '--config', self.args['configfile'],
+                        self.args['actionfile']
+                    ],
+                    )
+        self.assertEqual(
+            {'my_index1': {'aliases': {}}, 'my_index2': {'aliases': {}}},
+            self.client.indices.get_alias()
+        )
+        self.assertEqual(0, result.exit_code)
     def test_no_add_remove(self):
         alias = 'testalias'
         self.write_config(
