@@ -150,6 +150,83 @@ alias_add_remove = ('---\n'
 '          kind: prefix\n'
 '          value: my\n')
 
+alias_remove_index_not_there = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Add/remove specified indices from designated alias"\n'
+'    action: alias\n'
+'    options:\n'
+'      name: {0}\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    remove:\n'
+'      filters:\n'
+'        - filtertype: pattern\n'
+'          kind: prefix\n'
+'          value: {1}\n')
+
+alias_add_with_empty_remove = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Add/remove specified indices from designated alias"\n'
+'    action: alias\n'
+'    options:\n'
+'      name: {0}\n'
+'      warn_if_no_indices: True\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    remove:\n'
+'      filters:\n'
+'        - filtertype: pattern\n'
+'          kind: prefix\n'
+'          value: insertrickrollhere\n'
+'    add:\n'
+'      filters:\n'
+'        - filtertype: pattern\n'
+'          kind: prefix\n'
+'          value: my\n')
+
+alias_remove_with_empty_add = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Add/remove specified indices from designated alias"\n'
+'    action: alias\n'
+'    options:\n'
+'      name: {0}\n'
+'      warn_if_no_indices: True\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    remove:\n'
+'      filters:\n'
+'        - filtertype: pattern\n'
+'          kind: prefix\n'
+'          value: du\n'
+'    add:\n'
+'      filters:\n'
+'        - filtertype: pattern\n'
+'          kind: prefix\n'
+'          value: insertrickrollhere\n')
+
+alias_add_remove_empty = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Add/remove specified indices from designated alias"\n'
+'    action: alias\n'
+'    options:\n'
+'      name: {0}\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    remove:\n'
+'      filters:\n'
+'        - filtertype: pattern\n'
+'          kind: prefix\n'
+'          value: {1}\n'
+'    add:\n'
+'      filters:\n'
+'        - filtertype: pattern\n'
+'          kind: prefix\n'
+'          value: {2}\n')
+
 alias_no_add_remove = ('---\n'
 'actions:\n'
 '  1:\n'
@@ -188,6 +265,9 @@ allocation_test = ('---\n'
 '      key: {0}\n'
 '      value: {1}\n'
 '      allocation_type: {2}\n'
+'      wait_for_completion: {3}\n'
+'      wait_interval: 1\n'
+'      max_wait: -1\n'
 '      continue_if_exception: False\n'
 '      disable_action: False\n'
 '    filters:\n'
@@ -313,6 +393,43 @@ delete_proto = ('---\n'
 '        stats_result: {7}\n'
 '        epoch: {8}\n')
 
+delete_pattern_proto = ('---\n'
+                'actions:\n'
+                '  1:\n'
+                '    description: "Delete indices as filtered"\n'
+                '    action: delete_indices\n'
+                '    options:\n'
+                '      continue_if_exception: False\n'
+                '      disable_action: False\n'
+                '    filters:\n'
+                '      - filtertype: {0}\n'
+                '        source: {1}\n'
+                '        direction: {2}\n'
+                '        timestring: {3}\n'
+                '        unit: {4}\n'
+                '        unit_count: {5}\n'
+                '        unit_count_pattern: {6}\n')
+
+delete_period_proto = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Delete indices as filtered"\n'
+'    action: delete_indices\n'
+'    options:\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    filters:\n'
+'    - filtertype: {0}\n'
+'      source: {1}\n'
+'      range_from: {2}\n'
+'      range_to: {3}\n'
+'      timestring: {4}\n'
+'      unit: {5}\n'
+'      field: {6}\n'
+'      stats_result: {7}\n'
+'      epoch: {8}\n'
+'      week_starts_on: {9}\n')
+
 delete_ignore_proto = ('---\n'
 'actions:\n'
 '  1:\n'
@@ -397,6 +514,8 @@ snapshot_test = ('---\n'
 '    options:\n'
 '      repository: {0}\n'
 '      name: {1}\n'
+'      wait_interval: {2}\n'
+'      max_wait: {3}\n'
 '      continue_if_exception: False\n'
 '      disable_action: False\n'
 '    filters:\n'
@@ -462,6 +581,8 @@ restore_snapshot_proto = ('---\n'
 '      wait_for_completion: {10}\n'
 '      skip_repo_fs_check: {11}\n'
 '      timeout_override: {12}\n'
+'      wait_interval: {13}\n'
+'      max_wait: {14}\n'
 '      continue_if_exception: False\n'
 '      disable_action: False\n'
 '    filters:\n'
@@ -532,6 +653,8 @@ test_682 = ('---\n'
 '      repository: {0}\n'
 '      name: {1}\n'
 '      ignore_empty_list: {2}\n'
+'      wait_interval: {3}\n'
+'      max_wait: {4}\n'
 '      continue_if_exception: False\n'
 '      disable_action: False\n'
 '    filters:\n'
@@ -555,3 +678,152 @@ CRA_all = {
     u'persistent':{},
     u'transient':{u'cluster':{u'routing':{u'allocation':{u'enable':u'all'}}}}
 }
+
+rollover_one = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Rollover selected alias/index"\n'
+'    action: rollover\n'
+'    options:\n'
+'      name: {0}\n'
+'      conditions: \n'
+'        {1}: {2}\n'
+'      extra_settings:\n'
+'        index.number_of_shards: 1\n'
+'        index.number_of_replicas: 0\n')
+
+rollover_both = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Rollover selected alias/index"\n'
+'    action: rollover\n'
+'    options:\n'
+'      name: {0}\n'
+'      conditions: \n'
+'        max_age: {1}\n'
+'        max_docs: {2}\n'
+'      extra_settings:\n'
+'        index.number_of_shards: 1\n'
+'        index.number_of_replicas: 0\n')
+
+rollover_bad_settings = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Rollover selected alias/index"\n'
+'    action: rollover\n'
+'    options:\n'
+'      name: {0}\n'
+'      conditions: \n'
+'        max_age: {1}\n'
+'        max_docs: {2}\n'
+'      extra_settings:\n'
+'        foo: 1\n'
+'        bar: 0\n')
+
+rollover_with_name = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Rollover selected alias/index"\n'
+'    action: rollover\n'
+'    options:\n'
+'      name: {0}\n'
+'      conditions: \n'
+'        {1}: {2}\n'
+'      new_index: {3}\n'
+'      extra_settings:\n'
+'        index.number_of_shards: 1\n'
+'        index.number_of_replicas: 0\n')
+
+reindex = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Reindex"\n'
+'    action: reindex\n'
+'    options:\n'
+'      wait_interval: {0}\n'
+'      max_wait: {1}\n'
+'      request_body:\n'
+'        source:\n'
+'          index: {2}\n'
+'        dest:\n'
+'          index: {3}\n'
+'    filters:\n'
+'    - filtertype: none\n')
+remote_reindex = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Reindex from remote"\n'
+'    action: reindex\n'
+'    options:\n'
+'      wait_interval: {0}\n'
+'      max_wait: {1}\n'
+'      request_body:\n'
+'        source:\n'
+'          remote:\n'
+'            host: {2}\n'
+'          index: {3}\n'
+'        dest:\n'
+'          index: {4}\n'
+'      remote_filters:\n'
+'      - filtertype: pattern\n'
+'        kind: prefix\n'
+'        value: {5}\n'
+'    filters:\n'
+'    - filtertype: none\n')
+migration_reindex = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Reindex from remote"\n'
+'    action: reindex\n'
+'    options:\n'
+'      wait_interval: {0}\n'
+'      max_wait: {1}\n'
+'      migration_prefix: {2}\n'
+'      migration_suffix: {3}\n'
+'      request_body:\n'
+'        source:\n'
+'          remote:\n'
+'            host: {4}\n'
+'          index: {5}\n'
+'        dest:\n'
+'          index: {6}\n'
+'      remote_filters:\n'
+'      - filtertype: pattern\n'
+'        kind: prefix\n'
+'        value: {7}\n'
+'    filters:\n'
+'    - filtertype: none\n')
+test_945 = ('---\n'
+'actions:\n'
+'  1:\n'
+'    action: delete_indices\n'
+'    description: >-\n'
+'      Delete indices older than 7 days\n'
+'    options:\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    filters:\n'
+'    - filtertype: pattern\n'
+'      kind: prefix\n'
+'      value: logstash-\n'
+'      exclude:\n'
+'      - filtertype: age\n'
+'        source: name\n'
+'        direction: older\n'
+'        unit: days\n'
+'        unit_count: 7\n')
+index_settings = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Act on indices as filtered"\n'
+'    action: index_settings\n'
+'    options:\n'
+'      index_settings:\n'
+'        index:\n'
+'          {0}: {1}\n'
+'      ignore_unavailable: {2}\n'
+'      preserve_existing: {3}\n'
+'    filters:\n'
+'      - filtertype: pattern\n'
+'        kind: prefix\n'
+'        value: my\n')
\ No newline at end of file
