@@ -10,7 +10,7 @@ class TestActionSnapshot(TestCase):
         self.assertRaises(TypeError, curator.Snapshot, 'invalid')
     def test_init_no_repo_arg_exception(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
@@ -18,7 +18,7 @@ class TestActionSnapshot(TestCase):
         self.assertRaises(curator.MissingArgument, curator.Snapshot, ilo)
     def test_init_no_repo_exception(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
@@ -28,7 +28,7 @@ class TestActionSnapshot(TestCase):
             curator.ActionError, curator.Snapshot, ilo, repository='notfound')
     def test_init_no_name_exception(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
@@ -38,7 +38,7 @@ class TestActionSnapshot(TestCase):
             repository=testvars.repo_name)
     def test_init_success(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
@@ -50,12 +50,13 @@ class TestActionSnapshot(TestCase):
         self.assertIsNone(so.state)
     def test_get_state_success(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.snapshots
+        client.tasks.get.return_value = testvars.no_snap_tasks
         ilo = curator.IndexList(client)
         so = curator.Snapshot(ilo, repository=testvars.repo_name,
             name=testvars.snap_name)
@@ -63,24 +64,26 @@ class TestActionSnapshot(TestCase):
         self.assertEqual('SUCCESS', so.state)
     def test_get_state_fail(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = {'snapshots':[]}
+        client.tasks.get.return_value = testvars.no_snap_tasks
         ilo = curator.IndexList(client)
         so = curator.Snapshot(ilo, repository=testvars.repo_name,
             name=testvars.snap_name)
         self.assertRaises(curator.CuratorException, so.get_state)
     def test_report_state_success(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.snapshots
+        client.tasks.get.return_value = testvars.no_snap_tasks
         ilo = curator.IndexList(client)
         so = curator.Snapshot(ilo, repository=testvars.repo_name,
             name=testvars.snap_name)
@@ -88,12 +91,13 @@ class TestActionSnapshot(TestCase):
         self.assertEqual('SUCCESS', so.state)
     def test_report_state_other(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.highly_unlikely
+        client.tasks.get.return_value = testvars.no_snap_tasks
         ilo = curator.IndexList(client)
         so = curator.Snapshot(ilo, repository=testvars.repo_name,
             name=testvars.snap_name)
@@ -101,12 +105,13 @@ class TestActionSnapshot(TestCase):
         self.assertEqual('IN_PROGRESS', so.state)
     def test_do_dry_run(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.snapshots
+        client.tasks.get.return_value = testvars.no_snap_tasks
         client.snapshot.create.return_value = None
         client.snapshot.status.return_value = testvars.nosnap_running
         client.snapshot.verify_repository.return_value = testvars.verified_nodes
@@ -116,13 +121,15 @@ class TestActionSnapshot(TestCase):
         self.assertIsNone(so.do_dry_run())
     def test_do_action_success(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.snapshots
-        client.snapshot.create.return_value = None
+        client.tasks.get.return_value = testvars.no_snap_tasks
+        client.snapshot.create.return_value = testvars.generic_task
+        client.tasks.get.return_value = testvars.completed_task
         client.snapshot.status.return_value = testvars.nosnap_running
         client.snapshot.verify_repository.return_value = testvars.verified_nodes
         ilo = curator.IndexList(client)
@@ -131,12 +138,13 @@ class TestActionSnapshot(TestCase):
         self.assertIsNone(so.do_action())
     def test_do_action_raise_snap_in_progress(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.snapshots
+        client.tasks.get.return_value = testvars.no_snap_tasks
         client.snapshot.create.return_value = None
         client.snapshot.status.return_value = testvars.snap_running
         client.snapshot.verify_repository.return_value = testvars.verified_nodes
@@ -146,13 +154,14 @@ class TestActionSnapshot(TestCase):
         self.assertRaises(curator.SnapshotInProgress, so.do_action)
     def test_do_action_no_wait_for_completion(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.snapshots
-        client.snapshot.create.return_value = None
+        client.tasks.get.return_value = testvars.no_snap_tasks
+        client.snapshot.create.return_value = testvars.generic_task
         client.snapshot.status.return_value = testvars.nosnap_running
         client.snapshot.verify_repository.return_value = testvars.verified_nodes
         ilo = curator.IndexList(client)
@@ -161,12 +170,13 @@ class TestActionSnapshot(TestCase):
         self.assertIsNone(so.do_action())
     def test_do_action_raise_on_failure(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '2.4.1'} }
+        client.info.return_value = {'version': {'number': '5.0.0'} }
         client.indices.get_settings.return_value = testvars.settings_one
         client.cluster.state.return_value = testvars.clu_state_one
         client.indices.stats.return_value = testvars.stats_one
         client.snapshot.get_repository.return_value = testvars.test_repo
         client.snapshot.get.return_value = testvars.snapshots
+        client.tasks.get.return_value = testvars.no_snap_tasks
         client.snapshot.create.return_value = None
         client.snapshot.create.side_effect = testvars.fake_fail
         client.snapshot.status.return_value = testvars.nosnap_running
